pub struct StreamSession { /* private fields */ }Expand description
Established WebTransport session used by the streaming loop.
Implementations
Sourceimpl StreamSession
impl StreamSession
Sourcepub fn remote_address(&self) -> SocketAddr
pub fn remote_address(&self) -> SocketAddr
Current peer address.
Sourcepub fn max_datagram_size(&self) -> Option<usize>
pub fn max_datagram_size(&self) -> Option<usize>
Maximum datagram payload permitted by the current path MTU estimate.
Sourcepub fn send_frame_packet(
&self,
packet: &FramePacket,
) -> Result<(), TransportError>
pub fn send_frame_packet( &self, packet: &FramePacket, ) -> Result<(), TransportError>
Send a single packetized frame fragment over QUIC datagram transport.
Sourcepub fn send_frame_packets(
&self,
packets: &[FramePacket],
) -> Result<(), TransportError>
pub fn send_frame_packets( &self, packets: &[FramePacket], ) -> Result<(), TransportError>
Send a batch of packetized frame fragments in order.
Sourcepub async fn recv_input_datagram(&self) -> Result<InputEvent, TransportError>
pub async fn recv_input_datagram(&self) -> Result<InputEvent, TransportError>
Receive the next unreliable input datagram from the browser.
Sourcepub async fn recv_reliable_input(&self) -> Result<InputEvent, TransportError>
pub async fn recv_reliable_input(&self) -> Result<InputEvent, TransportError>
Receive the next reliable input message from a uni- or bidirectional stream.
Sourcepub async fn recv_input(&self) -> Result<ReceivedInput, TransportError>
pub async fn recv_input(&self) -> Result<ReceivedInput, TransportError>
Receive the next input event, regardless of reliability mode.
Sourcepub async fn send_control_message(
&self,
payload: &[u8],
) -> Result<(), TransportError>
pub async fn send_control_message( &self, payload: &[u8], ) -> Result<(), TransportError>
Send a reliable control message to the browser using a unidirectional stream.